A2aMessage class final

A message in an A2A task.

Constructors

A2aMessage({required String role, required List<A2aPart> parts})
const
A2aMessage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parts → List<A2aPart>
final
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContent → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited