A2aPart class final

A message part: text or structured data.

Constructors

A2aPart({String? text, Map<String, dynamic>? data})
const
A2aPart.fromJson(Map<String, dynamic> json)
factory

Properties

data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited