A2aTask class final

A2A Task: a stateful unit of work with messages and artifacts.

Constructors

A2aTask({required String id, required A2aTaskState state, List<A2aMessage>? messages, List<A2aArtifact>? artifacts})
A2aTask.fromJson(Map<String, dynamic> json)
factory

Properties

artifacts List<A2aArtifact>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
messages List<A2aMessage>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state A2aTaskState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited