AbortedError class final

Thrown internally when a CancelToken fires; caught and converted into an aborted ErrorEvent. Never escapes an adapter.

Implemented types

Constructors

AbortedError()
Creates an abort marker error.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited