AgentLoopTurnUpdate class final

Replacement runtime state used by the loop before another provider request. Ported subset of pi's AgentLoopTurnUpdate (no thinkingLevel: reasoning levels are not ported yet).

Constructors

AgentLoopTurnUpdate({Context? context, Model? model})
const

Properties

context Context?
Context for the next provider request. null keeps the current one.
final
hashCode int
The hash code for this object.
no setterinherited
model Model?
Model for the next provider request. null keeps the current one.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited