AgentUrlException class final

Thrown when an agent:// URL cannot be resolved (port of omp's model-visible protocol errors).

Implemented types

Constructors

AgentUrlException(String message)
Creates an AgentUrlException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The model-facing error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited