ApiKeyCredential class final

One credential in an ApiKeyRing: its secrets-store name and secret value. The value must never be logged or sent to the model.

Constructors

ApiKeyCredential(String name, String value)
Creates a credential pair.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The secrets-store name (e.g. OPENAI_API_KEY_2).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The secret value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited