ApprovalOutcome class final

The outcome of an ApprovalManager.authorize check.

Constructors

ApprovalOutcome.allowed()
The call may execute.
const
ApprovalOutcome.denied(String reason)
The call is refused; reason goes into the error tool result.
const

Properties

allowed bool
Whether the tool call may execute.
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
Denial reason shown to the model (and user); null when allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited