ApprovalPolicy enum
The resolved policy for one tool call.
Values
- allow → const ApprovalPolicy
-
Execute without asking.
- deny → const ApprovalPolicy
-
Refuse execution; the model receives an error tool result.
- prompt → const ApprovalPolicy
-
Ask the user (via the ApprovalPrompt callback) before executing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ApprovalPolicy> - A constant List of the values in this enum, in order of their declaration.