ArchiveNode class final

Metadata for one archive node (omp's ArchiveNode).

Implementers

Constructors

ArchiveNode({required String path, required bool isDirectory, required int size})
Creates a node.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
Whether this node is a directory.
final
path String
Normalized full path inside the archive.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Uncompressed size in bytes (0 for directories).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited