AssistantMetricDetail class final

Recorded inputs needed to derive assistant TTFT and decode throughput.

Constructors

AssistantMetricDetail({required bool timingRecorded, DateTime? stepStartTime, DateTime? firstTokenTime, DateTime? completedTime, required bool usageProvided, int? outputTokens})
Creates an AssistantMetricDetail.
const

Properties

completedTime DateTime?
When the response completed.
final
firstTokenTime DateTime?
Time to first token marker.
final
hashCode int
The hash code for this object.
no setterinherited
outputTokens int?
Output token count, when known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepStartTime DateTime?
When the request was issued.
final
timingRecorded bool
Whether any wall-clock timing was recorded for the step.
final
usageProvided bool
Whether the provider reported usage for the step.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited