waitFor abstract method
Waits until text appears or selector matches, up to timeoutMs.
Implementation
Future<BrowserWaitResult> waitFor({
String? selector,
String? text,
required int timeoutMs,
int? tabId,
});
Waits until text appears or selector matches, up to timeoutMs.
Future<BrowserWaitResult> waitFor({
String? selector,
String? text,
required int timeoutMs,
int? tabId,
});