ChildMessageReader typedef
Callback to read the last N messages from a child's session.
Implementation
typedef ChildMessageReader =
Future<List<(String role, String text)>> Function(
String sessionId, {
int tail,
});
Callback to read the last N messages from a child's session.
typedef ChildMessageReader =
Future<List<(String role, String text)>> Function(
String sessionId, {
int tail,
});