sessionList property
The fa session <verb> subcommand (issue #198), when the invocation
routed to the session lister instead of a prompt run.
Implementation
final SessionCliCommand? sessionList;
The fa session <verb> subcommand (issue #198), when the invocation
routed to the session lister instead of a prompt run.
final SessionCliCommand? sessionList;