CliArgsException class final

Invalid command line: the executable prints message plus a usage hint to stderr and exits with code 64 (EX_USAGE).

Implemented types

Constructors

CliArgsException(String message)
Creates a CliArgsException.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The human-readable error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited