CliArgsVersion class final

--version was passed: print the version and exit 0. output carries --output json (issue #155): machine-readable version + HEP version.

Inheritance

Constructors

CliArgsVersion({String? output})
Creates a CliArgsVersion.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
output String?
--output <mode> when combined with --version ('json').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited