CollectBranchEntries typedef

CollectBranchEntries = ({String? commonAncestorId, List<SessionRecord> entries})

Entries collected for a branch summary plus the common ancestor between the old and the new position.

Implementation

typedef CollectBranchEntries = ({
  List<SessionRecord> entries,
  String? commonAncestorId,
});