ConfigException class

Thrown when harness configuration is invalid (e.g. malformed config files or missing required settings).

Inheritance
Implementers

Constructors

ConfigException(String message, {Object? cause, StackTrace? causeStack})
Creates a ConfigException.
const

Properties

cause → Object?
The original error that caused this exception, if any.
finalinherited
causeStack → StackTrace?
The stack trace of the original error, if any.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable description of what went wrong.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited