ConfigPathInfo class final

One config file location reported by ConfigService.paths.

Constructors

ConfigPathInfo(String label, String path, bool exists)
const

Properties

exists → bool
Whether the file exists.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
Human label (global config, project config, project rules, ...).
final
path → String
Absolute path (or a host note in place of the path).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited