ConfigSetResult class final

Result of ConfigService.set.

Constructors

ConfigSetResult({required String key, required String file, required String scope, required String oldDisplay, required String newDisplay, required String application})
const

Properties

application String
Whether/when the change applies at runtime (live re-read surface or next boot).
final
file String
The file that was edited.
final
hashCode int
The hash code for this object.
no setterinherited
key String
The dotted key that was written.
final
newDisplay String
The value that was written.
final
oldDisplay String
The previous value display, (absent) when the key was not set.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
global or project.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited