ContentBlock class sealed

A content block of a Message.

Sealed counterpart of pi's TextContent | ThinkingContent | ToolCall | ImageContent unions.

Implementers

Constructors

ContentBlock.fromJson(Map<String, dynamic> json)
Deserializes a JSON map produced by toJson, dispatching on type.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes to a JSON map with a type discriminator (pi shape).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited