CubeBackendMode enum

How commands are confined: policy (the Phase 1 default) or kernel (wrapped in the OS sandbox primitive of the host platform — sandbox-exec on macOS, unshare on Linux).

Inheritance
Available extensions

Values

policy → const CubeBackendMode

Dart policy layers only — the Phase 1 default.

kernel → const CubeBackendMode

OS kernel confinement for the host platform, on top of the Dart layers. On a platform without an enforcing backend a kernel spec is REFUSED (fail-closed) unless the spec opts into the fallback via CubeSpec.allowDegrade.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Object? node, String where) → CubeBackendMode
Parses the spec.backend: label, throwing ConfigException on an unknown value.

Constants

values → const List<CubeBackendMode>
A constant List of the values in this enum, in order of their declaration.