CubeEnvValue class final

A variable with a literal value.

Inheritance

Constructors

CubeEnvValue({required String name, required String value})
Creates a literal variable.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The variable name (e.g. FAH_MODE).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The literal value injected into the child environment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited