CubePathAccess enum

Access level granted for a path.

Inheritance
Available extensions

Values

readOnly → const CubePathAccess

Read-only (ro in the cube yaml).

const CubePathAccess('ro')
readWrite → const CubePathAccess

Read and write (rw in the cube yaml).

const CubePathAccess('rw')
deny → const CubePathAccess

No access at all (deny in the cube yaml).

const CubePathAccess('deny')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
The config-file label.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String label, String where) → CubePathAccess
Parses label, throwing ConfigException on an unknown level.

Constants

values → const List<CubePathAccess>
A constant List of the values in this enum, in order of their declaration.