authMethod property
How this entry authenticates. Used to pick the right path when switching to saved SSO/JWT providers.
Implementation
CustomProviderAuthMethod authMethod;
How this entry authenticates. Used to pick the right path when switching to saved SSO/JWT providers.
CustomProviderAuthMethod authMethod;