CutPointResult class final

Cut point selected for compaction.

Ported from pi's CutPointResult.

Constructors

CutPointResult({required int firstKeptEntryIndex, required int turnStartIndex, required bool isSplitTurn})
Creates a CutPointResult.
const

Properties

firstKeptEntryIndex int
Index of the first entry retained after compaction.
final
hashCode int
The hash code for this object.
no setterinherited
isSplitTurn bool
Whether the selected cut point splits an in-progress turn.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnStartIndex int
Index of the turn-start entry when the cut splits a turn, otherwise -1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited