Base interface for a fah plugin / package extension.
- Implementers
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginContext context) → void -
Called once when the CLI starts. Use
contextto register tools, hooks, slash commands, and read plugin-specificcontext.config. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited