FileErrorCode enum

Stable, backend-independent error codes returned by FileSystem operations.

Ported from pi's FileErrorCode union.

Inheritance
Available extensions

Values

aborted → const FileErrorCode

The operation was aborted.

notFound → const FileErrorCode

The addressed path does not exist.

permissionDenied → const FileErrorCode

The operation was denied by the platform.

notDirectory → const FileErrorCode

A path component that must be a directory is not one.

isDirectory → const FileErrorCode

The addressed path is a directory but a file was required.

invalid → const FileErrorCode

The operation is invalid for the addressed path.

notSupported → const FileErrorCode

The backend does not support the operation.

unknown → const FileErrorCode

Any other backend failure.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FileErrorCode>
A constant List of the values in this enum, in order of their declaration.