HashlineAnchor class final

A line-number anchor (1-indexed).

Constructors

HashlineAnchor(int line)
Creates an anchor on line (1-indexed).
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
line → int
The 1-indexed line number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited