HashlineApplyResult class final

Result of applying a parsed set of edits to a text body.

Constructors

HashlineApplyResult({required String text, int? firstChangedLine, List<String> warnings = const []})
Creates a result with the post-edit text.
const

Properties

firstChangedLine int?
First line number (1-indexed) that changed, or null for a no-op apply.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Post-edit text body.
final
warnings List<String>
Diagnostic warnings collected by the parser or patcher.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited