HashlineCursorAfter class final

Insert immediately after anchor (INS.POST N:).

Inheritance

Constructors

HashlineCursorAfter(HashlineAnchor anchor)
const

Properties

anchor HashlineAnchor
The anchor line the payload lands behind.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited