HtmlText class final

A plain-text chunk between tags.

Constructors

HtmlText(String text, int offset)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → int
Offset in the source where the chunk starts.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Raw (still entity-encoded) text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited