ImageRegistryEntry class final

One unique image in the window.

Constructors

ImageRegistryEntry({required int index, required String key, required String data, required String mimeType})
const

Properties

data → String
Base64 payload (data-URL bytes).
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
First-seen-order index inside the window (the N of [Image N]).
final
key → String
Content key of the canonical payload string.
final
mimeType → String
Mime type of the payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited