LspServerUnavailableException class final

Thrown by an LspTransportFactory when the server process cannot be started (e.g. the command is not on PATH). The lsp tool converts this into a clean error result — never a crash.

Implemented types

Constructors

LspServerUnavailableException(String message, {Object? cause})
Creates an LspServerUnavailableException.
const

Properties

cause Object?
The original error, when available.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited