LspTextEdit class final

LSP text edit: replace range with newText.

Constructors

LspTextEdit({required LspRange range, required String newText})
Creates an LspTextEdit.
const
LspTextEdit.fromJson(Map<String, dynamic> json)
Parses a JSON {"range": ..., "newText": ...} map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newText String
The replacement text.
final
range LspRange
The replaced range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited