MailboxEntry class

One entry in the messaging-fabric directory.

Constructors

MailboxEntry({required String id, String? cwd, String? slug})
Creates a directory entry with optional cwd and slug metadata.
const

Properties

cwd String?
The working directory this mailbox belongs to, when known.
final
hashCode int
The hash code for this object.
no setteroverride
id String
The mailbox id (e.g. a1, sess1/main).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
The session slug this mailbox belongs to, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override