maxMaintenanceAge constant
Duration
const maxMaintenanceAge
Maintenance cadence: due when the last run is older than 24 h.
Implementation
static const maxMaintenanceAge = Duration(hours: 24);
Maintenance cadence: due when the last run is older than 24 h.
static const maxMaintenanceAge = Duration(hours: 24);