MemoryEntry class final

A single memory entry returned by MemoryController.search / list.

Constructors

MemoryEntry({required String id, required String type, required String text, List<String> tags = const [], double importance = 0.5, String scope = 'project'})
const

Properties

displayLine → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
importance → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
final
tags → List<String>
final
text → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited