joinPath method
Joins path segments in the filesystem namespace without requiring the result to exist.
Implementation
@override
Future<Result<String, FileError>> joinPath(List<String> parts) async {
return Ok(_normalize(parts.join('/')));
}
Joins path segments in the filesystem namespace without requiring the result to exist.
@override
Future<Result<String, FileError>> joinPath(List<String> parts) async {
return Ok(_normalize(parts.join('/')));
}