MessageEndEvent class final
A message is complete: the final assistant message, a prompt, or a tool result.
- Inheritance
-
- Object
- AgentEvent
- MessageEndEvent
Constructors
- MessageEndEvent(Message message)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited