MessageStartEvent class final

A message entered the transcript: a prompt, a (partial) assistant message, or a tool result.

Inheritance

Constructors

MessageStartEvent(Message message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message Message
The message. For assistant messages this is the first partial snapshot.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited