MobileAppEntry class final
One installed app in an inventory listing.
Constructors
- MobileAppEntry({required String packageName, String? label})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
User-visible label when resolved.
final
- packageName → String
-
Package id, e.g.
com.android.settings.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited