MobileObserveResult class final

The outcome of one observe step.

Constructors

MobileObserveResult({required String xml, required MobileScreenshot screenshot, required Duration took})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshot → MobileScreenshot
The concurrently captured screen.
final
took → Duration
Wall-clock time the step took.
final
xml → String
Raw hierarchy XML (parse with parseMobileHierarchy).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited