MobileShellResult class final

The outcome of a Shizuku shell command.

Constructors

MobileShellResult({required int exitCode, String stdout = '', String stderr = ''})
const

Properties

exitCode int
Process exit code.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
Stderr.
final
stdout String
Combined stdout (before stderr, like the bash tool's output shape).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited