MobileTapById class final
Tap the center of the element with this index id (e12).
- Inheritance
-
- Object
- MobileTapTarget
- MobileTapById
Constructors
- MobileTapById(String elementId)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited