promptBlob property
The full system prompt sent with this request (issue #385 F1), for hosts to persist once per content hash. Null when the request had no system prompt.
Implementation
final TrajectoryPromptBlob? promptBlob;
The full system prompt sent with this request (issue #385 F1), for hosts to persist once per content hash. Null when the request had no system prompt.
final TrajectoryPromptBlob? promptBlob;