newMessages property
The messages this run will return if it exits now (prompts included for agentLoop/runAgentLoop, excluded for continuations).
Implementation
final List<Message> newMessages;
The messages this run will return if it exits now (prompts included for agentLoop/runAgentLoop, excluded for continuations).
final List<Message> newMessages;