OperativePinDiff class

The P4/P5 change report between two pin registries.

Properties

dropped → List<OperativePin>
Pins whose owner skills are gone (P4).
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether anything changed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superseded → List<({OperativePin current, OperativePin previous})>
Pins replaced by a new content key of the same owner skill (P5).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notices() → List<String>
Human-readable notices, one per change.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited