ResolvedSkillAvailability class final

The availability decision for one skill.

Constructors

ResolvedSkillAvailability({required bool enabled, required SkillToggleScope? scope})
const

Properties

enabled → bool
Whether the skill is invocable, suggested, and listed for the model.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → SkillToggleScope?
The deepest scope that mentioned the skill, or null when no scope declared it (default-on).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited