errorOrNull property
E?
get
errorOrNull
The failure error, or null when this is an Ok.
Implementation
E? get errorOrNull => switch (this) {
Ok<T, E>() => null,
Err<T, E>(:final error) => error,
};
The failure error, or null when this is an Ok.
E? get errorOrNull => switch (this) {
Ok<T, E>() => null,
Err<T, E>(:final error) => error,
};