valueOrNull property
T?
get
valueOrNull
The success value, or null when this is an Err.
Implementation
T? get valueOrNull => switch (this) {
Ok<T, E>(:final value) => value,
Err<T, E>() => null,
};
The success value, or null when this is an Err.
T? get valueOrNull => switch (this) {
Ok<T, E>(:final value) => value,
Err<T, E>() => null,
};