SqlitePathCandidate class final

One {sqlitePath, subPath, queryString} split of a db.sqlite:table?query reference (omp's SqlitePathCandidate).

Constructors

SqlitePathCandidate(String sqlitePath, String subPath, String queryString)
Creates a candidate.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
queryString String
Query string after the first ? (may be empty).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlitePath String
Path to the database file itself.
final
subPath String
Table/row selector after the database path.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited