SqliteRawSelector class final

db.sqlite?q=SELECT … — raw read-only SQL.

Inheritance

Constructors

SqliteRawSelector(String sql)
Creates a raw selector.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
The SQL to run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited