SqliteRowSelector class final

db.sqlite:table:key — row lookup by primary key (or rowid).

Inheritance

Constructors

SqliteRowSelector(String table, String key)
Creates a row selector.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Key value as written in the path.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
Table name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited