SqliteTablePage class final

A paged table query result with the total row count for continuation notes (omp's queryRows return shape).

Constructors

SqliteTablePage({required List<String> columns, required List<Map<String, Object?>> rows, required int totalCount})
Creates a page.
const

Properties

columns List<String>
Column names in schema order.
final
hashCode int
The hash code for this object.
no setterinherited
rows List<Map<String, Object?>>
The page rows.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
Total rows matching the (optional) WHERE clause.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited