SqliteTableSummary class final
Row count for a table in the listing: exact when the table is provably
small, otherwise a lower bound (omp's TableRowCount, minus the
sqlite_stat1 estimate variant).
Constructors
- SqliteTableSummary(String name, int rows, {bool exact = true})
-
Creates a summary.
const
Properties
- exact → bool
-
Whether rows is the exact count.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Table name.
final
- rows → int
-
Row count (exact, or a lower bound when exact is false).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited