SseParser class final

Incrementally parses a UTF-8 SSE byte stream into SseEvents.

Constructors

SseParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(List<int> chunk) → List<SseEvent>
Feeds chunk; returns every event completed by it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited