StartEvent class final
Emitted once before any content events.
- Inheritance
-
- Object
- AssistantMessageEvent
- StartEvent
Constructors
- StartEvent({required AssistantMessage partial})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partial → AssistantMessage
-
The live partial message as of this event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited