clock property
The manager's clock, stamped into createdAt/lastActivity.
Injectable so tests drive spawn ages and stall windows
deterministically (issue #383 heartbeat).
Implementation
final DateTime Function() clock;
The manager's clock, stamped into createdAt/lastActivity.
Injectable so tests drive spawn ages and stall windows
deterministically (issue #383 heartbeat).
final DateTime Function() clock;