SummarizationRequest class final

A single summarization request handed to a SummarizeFn.

Constructors

SummarizationRequest({required String prompt, CancelToken? cancelToken})
Creates a SummarizationRequest.
const

Properties

cancelToken → CancelToken?
Cancellation for the underlying LLM call, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
prompt → String
The full user prompt (serialized conversation + instructions).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited