TextDeltaEvent class final

Incremental text for the block at contentIndex.

Inheritance

Constructors

TextDeltaEvent({required int contentIndex, required String delta, required AssistantMessage partial})
const

Properties

contentIndex int
Index into AssistantMessage.content of the block this event concerns.
final
delta String
The newly arrived text fragment.
final
hashCode int
The hash code for this object.
no setterinherited
partial AssistantMessage
The live partial message as of this event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited