ToolExecutionEndEvent class final

Execution of a tool call finished (successfully or with an error result).

Inheritance

Constructors

ToolExecutionEndEvent({required String toolCallId, required String toolName, required ToolExecutionResult result, required bool isError})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isError bool
Whether the result is an error (unknown tool, executor threw, blocked, aborted, or truncated arguments).
final
result ToolExecutionResult
The final result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallId String
The ToolCall.id that was executed.
final
toolName String
The tool's name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited