ToolExecutionStartEvent class final

Execution of a tool call started.

Inheritance

Constructors

ToolExecutionStartEvent({required String toolCallId, required String toolName, required Map<String, dynamic> args})
const

Properties

args Map<String, dynamic>
The parsed tool call arguments.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallId String
The ToolCall.id being executed.
final
toolName String
The tool's name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited