stopThreshold property
Consecutive identical failures before the identical call is refused for the rest of the run.
Implementation
final int stopThreshold;
Consecutive identical failures before the identical call is refused for the rest of the run.
final int stopThreshold;