unknownRecordCount property
How many record kinds the builder did not know rendered as
unknown record context rows (F6: the ledger is provably lossless).
Implementation
final int unknownRecordCount;
How many record kinds the builder did not know rendered as
unknown record context rows (F6: the ledger is provably lossless).
final int unknownRecordCount;