TrajectoryTimelineModel class final

Full-domain model used by the overview.

Constructors

TrajectoryTimelineModel({required double start, required double end, required List<TrajectoryTimelineSpan> spans, required List<TrajectoryTimelineTurnBoundary> turnBoundaries})
Creates a TrajectoryTimelineModel.
const

Properties

end double
Inclusive domain upper bound.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans List<TrajectoryTimelineSpan>
Spans in ledger order.
final
start double
Inclusive domain lower bound.
final
turnBoundaries List<TrajectoryTimelineTurnBoundary>
Turn boundaries in ledger order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited