TurnEndEvent class final

A turn finished: the assistant message completed and its tool calls (if any) produced toolResults.

Inheritance

Constructors

TurnEndEvent({required AssistantMessage message, required List<ToolResultMessage> toolResults})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message AssistantMessage
The completed assistant message of this turn.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolResults List<ToolResultMessage>
Tool results produced this turn, in assistant source order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited