UsageChainScanner class final

Scans raw session-chain JSONL lines into UsageChainScan.

Constructors

UsageChainScanner()
Creates a UsageChainScanner.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(Iterable<String> lines) → UsageChainScan
Scans lines (the session file's raw lines, header included).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited