WireUnknownCommand class final

A command whose kind this library does not know: the passthrough form.

Inheritance

Constructors

WireUnknownCommand({required String kind, Map<String, dynamic> raw = const {}})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → String
The original (unknown) kind name.
final
raw → Map<String, dynamic>
The raw frame as received.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({int version = wireProtocolVersion}) → Map<String, dynamic>
The canonical frame for this command at version.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited