compactionSummaryPrefix top-level constant

String const compactionSummaryPrefix

Prefix wrapping a compaction summary when it is projected into the model context. Ported from pi's COMPACTION_SUMMARY_PREFIX.

Implementation

const compactionSummaryPrefix =
    'The conversation history before this point was compacted into the '
    'following summary:\n\n<summary>\n';