formatHashlineHeader function
Formats a hashline section header for a file path and snapshot tag.
Implementation
String formatHashlineHeader(String filePath, String fileHash) {
return '$hlFilePrefix$filePath$hlFileHashSep$fileHash$hlFileSuffix';
}
Formats a hashline section header for a file path and snapshot tag.
String formatHashlineHeader(String filePath, String fileHash) {
return '$hlFilePrefix$filePath$hlFileHashSep$fileHash$hlFileSuffix';
}