hlHeaderColon top-level constant
String
const hlHeaderColon
Colon terminating a hunk header that takes a body.
Implementation
const hlHeaderColon = ':';
Colon terminating a hunk header that takes a body.
const hlHeaderColon = ':';