hlInsertAfter top-level constant
String
const hlInsertAfter
Insert position keyword for inserting after a concrete line.
Implementation
const hlInsertAfter = 'POST';
Insert position keyword for inserting after a concrete line.
const hlInsertAfter = 'POST';