hlInsertBefore top-level constant
String
const hlInsertBefore
Insert position keyword for inserting before a concrete line.
Implementation
const hlInsertBefore = 'PRE';
Insert position keyword for inserting before a concrete line.
const hlInsertBefore = 'PRE';