hlInsertHead top-level constant
String
const hlInsertHead
Insert position keyword for inserting at the start of the file.
Implementation
const hlInsertHead = 'HEAD';
Insert position keyword for inserting at the start of the file.
const hlInsertHead = 'HEAD';