hlInsertTail top-level constant
String
const hlInsertTail
Insert position keyword for inserting at the end of the file.
Implementation
const hlInsertTail = 'TAIL';
Insert position keyword for inserting at the end of the file.
const hlInsertTail = 'TAIL';