ChatGptOAuthCallback class final

Constructors

ChatGptOAuthCallback({String? code, String? state, String? error, String? errorDescription})
const

Properties

code → String?
final
error → String?
final
errorDescription → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited