CodeMieSsoCallbackServer class final

Constructors

CodeMieSsoCallbackServer()

Properties

hashCode int
The hash code for this object.
no setterinherited
port int?
The bound port (null before start).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({Duration timeout = const Duration(minutes: 5)}) Future<int>
Starts the server on a random free loopback port; resolves the port.
toString() String
A string representation of this object.
inherited
waitForToken() Future<String?>
Resolves the raw token query parameter of the callback (null on timeout/cancel).

Operators

operator ==(Object other) bool
The equality operator.
inherited