exitCode property

  1. @override
Future<int> get exitCode
override

Completes with the server's exit code when the process ends, normally or not. Completes with an error when the exit cannot be determined.

Implementation

@override
Future<int> get exitCode => _process.exitCode;