absolutePath method
Returns an absolute addressed path without requiring it to exist and without resolving symlinks.
Implementation
@override
Future<Result<String, FileError>> absolutePath(String path) =>
_fs.absolutePath(path);
Returns an absolute addressed path without requiring it to exist and without resolving symlinks.
@override
Future<Result<String, FileError>> absolutePath(String path) =>
_fs.absolutePath(path);