isProtected property
bool
get
isProtected
True when this hub requires a credential on the WS upgrade.
Implementation
bool get isProtected => _masterSecret != null;
True when this hub requires a credential on the WS upgrade.
bool get isProtected => _masterSecret != null;