SecureKeyRunResult class final

Result of one helper-process invocation.

Constructors

SecureKeyRunResult(int exitCode, String stdout)
Creates a result with the process exitCode and captured stdout.
const

Properties

exitCode int
The process exit code.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stdout String
Captured standard output.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited