Validation for fa_network agent names, matching the server-side rule
(^[a-z0-9][a-z0-9-]{2,63}$ — 3–64 chars, lowercase letters, digits and
hyphens, must start with a letter or digit). Reused by the UI.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited