FanetApiException class final
The fa_network server answered with an unexpected HTTP status.
- Inheritance
-
- Object
- FanetException
- FanetApiException
Constructors
- FanetApiException(String message, {required int statusCode, required String bodyExcerpt})
-
Creates a FanetApiException for
statusCode, carrying a truncatedbodyExcerptof the response body for diagnostics.const
Properties
- bodyExcerpt → String
-
Truncated response body, for diagnostics.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of what went wrong.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code returned by the server.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited