FanetJoinResult class final
Result of POST /api/networks/{id}/join: the bearer token used for all
authenticated fa_network calls.
Constructors
- FanetJoinResult({required String sessionToken})
-
Creates a join result.
const
-
FanetJoinResult.fromJson(Map<
String, Object?> json) -
Parses the join response, ignoring extra fields such as
network,member, orrole.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionToken → String
-
The session token authenticating this member (Bearer credential).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited