AfterToolCallContext class final

Context passed to AfterToolCallHook.

Ported from pi's AfterToolCallContext (minus args/details).

Constructors

AfterToolCallContext({required AssistantMessage assistantMessage, required ToolCall toolCall, required ToolExecutionResult result, required bool isError, required Context context})
const

Properties

assistantMessage AssistantMessage
The assistant message that requested the tool call.
final
context Context
The loop's context at the time the tool call is finalized.
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
Whether the executed result is currently treated as an error.
final
result ToolExecutionResult
The executed tool result before any overrides are applied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCall ToolCall
The raw tool call block from AssistantMessage.content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited