AgentMode class final
A system-prompt mode for the CLI (e.g. /architect, /code, /review).
Constructors
Properties
- description → String
-
Short help description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Mode command name (without the leading
/).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemPrompt → String
-
Full system prompt used while this mode is active.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited