AgentUrlResolution class final
A resolved agent:// resource.
Constructors
-
AgentUrlResolution({required String id, required String content, required String contentType, List<
String> notes = const []}) -
Creates an AgentUrlResolution.
const
Properties
- content → String
-
The resolved content (pretty-printed JSON after extraction).
final
- contentType → String
-
text/markdownfor raw outputs,application/jsonafter extraction.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The id the URL resolved to (a nested id when the URL hopped the
hierarchy).
final
-
notes
→ List<
String> -
Resolution notes (e.g. the applied extraction query).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited