ApprovalTier enum
How much damage a tool call can do, worst case.
Values
- read → const ApprovalTier
-
Reads data without mutating workspace state (
read,ls). - write → const ApprovalTier
-
Mutates workspace/session state without executing arbitrary code (
write,edit). - exec → const ApprovalTier
-
Executes code, shells out, or performs similarly broad actions (
bash). Default for tools that do not declare a tier.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ApprovalTier> - A constant List of the values in this enum, in order of their declaration.