ArchiveDirectoryEntry class final
A direct child of an archive directory (omp's ArchiveDirectoryEntry).
- Inheritance
-
- Object
- ArchiveNode
- ArchiveDirectoryEntry
Constructors
- ArchiveDirectoryEntry({required String path, required bool isDirectory, required int size, required String name})
-
Creates a directory entry.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirectory → bool
-
Whether this node is a directory.
finalinherited
- name → String
-
Basename within the listed directory.
final
- path → String
-
Normalized full path inside the archive.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Uncompressed size in bytes (0 for directories).
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited