ChatGptOAuthCredentials class final
OAuth credentials issued for a ChatGPT account.
Constructors
- ChatGptOAuthCredentials({required String accessToken, required String refreshToken, required String idToken, String? accountId, DateTime? expiresAt})
-
const
- ChatGptOAuthCredentials.decode(String value)
-
factory
Properties
- accessToken → String
-
final
- accountId → String?
-
final
- expiresAt → DateTime?
-
When the access token expires, in UTC; null when unknown.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idToken → String
-
final
- refreshToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → String -
needsRefresh(
DateTime now, {Duration skew = const Duration(seconds: 60)}) → bool -
Whether
nowis at or past expiry minusskew. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited