CodexRateLimitWindow class final
One Codex usage window, as advertised by the ChatGPT backend.
Constructors
- CodexRateLimitWindow({required double usedPercent, int? windowMinutes, int? resetsAt})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resetsAt → int?
-
Unix epoch seconds at which the window resets, when advertised.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usedPercent → double
-
final
- windowMinutes → int?
-
Window length in minutes, when advertised.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited