CodexRateLimits class final
Codex usage limits from a ChatGPT backend response.
Constructors
- CodexRateLimits({CodexRateLimitWindow? primary, CodexRateLimitWindow? secondary, String? limitName})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limitName → String?
-
final
- primary → CodexRateLimitWindow?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → CodexRateLimitWindow?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited