CollectBranchEntries typedef
Entries collected for a branch summary plus the common ancestor between the old and the new position.
Implementation
typedef CollectBranchEntries = ({
List<SessionRecord> entries,
String? commonAncestorId,
});
Entries collected for a branch summary plus the common ancestor between the old and the new position.
typedef CollectBranchEntries = ({
List<SessionRecord> entries,
String? commonAncestorId,
});