ConfigSetResult class final
Result of ConfigService.set.
Constructors
Properties
- application → String
-
Whether/when the change applies at runtime (live re-read surface or
next boot).
final
- file → String
-
The file that was edited.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The dotted key that was written.
final
- newDisplay → String
-
The value that was written.
final
- oldDisplay → String
-
The previous value display,
(absent)when the key was not set.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
globalorproject.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited