DoneEvent class final
Terminal event: the message completed successfully.
- Inheritance
-
- Object
- AssistantMessageEvent
- DoneEvent
Constructors
- DoneEvent({required StopReason reason, required AssistantMessage message})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → AssistantMessage
-
The final message.
final
- partial → AssistantMessage
-
The live partial message as of this event.
no setteroverride
- reason → StopReason
-
Why the model stopped. One of StopReason.stop, StopReason.length,
or StopReason.toolUse.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited