ExecutionError class final

Error returned by Shell.exec.

Ported from pi's ExecutionError.

Implemented types

Constructors

ExecutionError(ExecutionErrorCode code, String message, {Object? cause})
Creates an ExecutionError with a code and message.
const

Properties

cause Object?
The original backend error, when available.
final
code ExecutionErrorCode
Backend-independent error code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited