ExecutionErrorCode enum
Stable, backend-independent error codes returned by Shell.exec.
Ported from pi's ExecutionErrorCode union.
Values
- aborted → const ExecutionErrorCode
-
The command was aborted via ShellExecOptions.cancelToken.
- timeout → const ExecutionErrorCode
-
The command exceeded ShellExecOptions.timeout.
-
No shell is available in this environment (e.g. web).
- spawnError → const ExecutionErrorCode
-
The process could not be spawned.
- callbackError → const ExecutionErrorCode
-
An output callback threw.
- unknown → const ExecutionErrorCode
-
Any other failure.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExecutionErrorCode> - A constant List of the values in this enum, in order of their declaration.