FileError class final
Error returned by FileSystem operations.
Ported from pi's FileError.
- Implemented types
Constructors
Properties
- cause → Object?
-
The original backend error, when available.
final
- code → FileErrorCode
-
Backend-independent error code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the failure.
final
- path → String?
-
The addressed path associated with the failure, when available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited