FileInfo class final
Metadata for one filesystem object.
Ported from pi's FileInfo.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → FileKind
-
Object kind.
final
- mtimeMs → int
-
Modification time as milliseconds since the Unix epoch.
final
- name → String
-
Basename of path.
final
- path → String
-
Absolute, normalized addressed path. Symlinks are not followed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Size in bytes (0 for directories).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited