FileOperations class final
File paths touched by a compaction range.
Ported from pi's FileOperations.
Constructors
- FileOperations()
- Creates an empty FileOperations accumulator.
Properties
-
edited
→ Set<
String> -
Files modified by edit operations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
read
→ Set<
String> -
Files read but not necessarily modified.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
written
→ Set<
String> -
Files written by full-file write operations.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited