FloorTransports class final
Only transports exist on this platform: off always allowed,
transport(T) allowed iff T ⊆ transports, on allowed iff the
capability's default transports are all inside the floor.
- Inheritance
-
- Object
- CapabilityFloor
- FloorTransports
Constructors
-
FloorTransports(Set<
String> transports) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transports
→ Set<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited