FolderModelState class final
The model/provider triple saved for one project folder.
Constructors
- FolderModelState({required String providerKind, required String modelId, required String? baseUrl})
-
Creates a FolderModelState.
const
Properties
- baseUrl → String?
-
The endpoint base URL (
nullfor catalog-default endpoints).final - hashCode → int
-
The hash code for this object.
no setteroverride
- modelId → String
-
The model id as shown in
/model.final - providerKind → String
-
The provider kind (e.g.
openai-completions,anthropic).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override