HashlineDelete class final
Delete the line at anchor.
- Inheritance
-
- Object
- HashlineEdit
- HashlineDelete
Constructors
- HashlineDelete({required HashlineAnchor anchor, required int lineNum, required int index})
-
const
Properties
- anchor → HashlineAnchor
-
The line to remove.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Stable parse order, used to sequence edits that share a line.
finalinherited
- lineNum → int
-
1-indexed patch line the edit was parsed from (groups one hunk).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited