HashlinePatch class final
A parsed hashline patch — zero or more HashlinePatchSections, each
rooted at a [PATH#HASH] header.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
HashlinePatchSection> -
The parsed sections in patch order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String input, {String? fallbackPath}) → HashlinePatch -
Parses
inputinto a HashlinePatch.fallbackPathprovides a section path when the input lacks a header but contains recognizable hashline ops (omp'sSplitOptions.path). -
parseSingle(
String input, {String? fallbackPath}) → HashlinePatchSection -
Parses
inputand returns only the first section. Throws if the input has zero sections.