HashlineRange class final
A parsed [A.=B] line range (1-indexed, inclusive on both ends).
Constructors
- HashlineRange({required HashlineAnchor start, required HashlineAnchor end})
-
Creates a range from
starttoend.const
Properties
- end → HashlineAnchor
-
Last line of the range (inclusive).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → HashlineAnchor
-
First line of the range.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited