InspectImagePlugin class final
Plugin that contributes the inspect_image tool.
- Implemented types
Constructors
- InspectImagePlugin({Client? httpClient})
-
Creates the plugin with an optional HTTP client for testing.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → Client?
-
Optional HTTP client override (tests).
final
- name → String
-
Unique plugin name (matches the key in
.fah/packages.yaml).no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginContext context) → void -
Called once when the CLI starts. Use
contextto register tools, hooks, slash commands, and read plugin-specificcontext.config.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited