LeaseInspect class final
The lease state a drive-open finds on disk.
Constructors
- LeaseInspect.expired(SessionLease lease)
-
An expired lease of a dead owner (
lease) — free to take fresh.factory - LeaseInspect.free()
-
No sidecar on disk: the lease is free.
factory
- LeaseInspect.live(SessionLease lease)
-
A live lease held by
lease: openers are viewers.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lease → SessionLease?
-
The lease record when one exists on disk (live or expired), else
null. An expired lease is surfaced so the acquirer can warn naming
the dead owner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → LeaseState
-
The classification of the sidecar that was read.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited