LspRange class final

LSP range.

Constructors

LspRange({required LspPosition start, required LspPosition end})
Creates an LspRange.
const
LspRange.fromJson(Map<String, dynamic> json)
Parses a JSON {"start": ..., "end": ...} map.
factory

Properties

end LspPosition
End position (exclusive).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start LspPosition
Start position (inclusive).
final

Methods

format() String
1-indexed startLine:startChar-endLine:endChar for error messages (omp's formatRange).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON form for requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited