McpServerState class final
The live state of one configured server.
Constructors
-
McpServerState({required McpServerStatus status, String? error, List<
McpToolInfo> tools = const []}) -
Creates a state snapshot.
const
Properties
- error → String?
-
Why the last attempt failed (status McpServerStatus.failed).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → McpServerStatus
-
Lifecycle status.
final
-
tools
→ List<
McpToolInfo> -
The tools advertised by the server (status
McpServerStatus.connected).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited