OpenRouterOAuthKey class final
Result of a successful OAuth code exchange.
Constructors
- OpenRouterOAuthKey({required String key, String? keyHash, String? label})
-
Creates a result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The user-controlled OpenRouter API key.
final
- keyHash → String?
-
SHA-256 lowercase hex digest of key, used to build the user's key
settings/logs URLs (
https://openrouter.ai/keys/<hash>).final - label → String?
-
The optional
key_labelthat was sent with the authorization request.final - logsUrl → String?
-
The usage logs URL for the signed-in owner, or null when keyHash is
unavailable.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingsUrl → String?
-
The key settings URL for the signed-in owner, or null when keyHash is
unavailable.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited