PromptTemplate class final
A prompt template loaded from a markdown file.
Constructors
Properties
- argumentHint → String?
-
Optional argument hint for help text.
final
- content → String
-
Template body, after frontmatter removal.
final
- description → String
-
Short description from frontmatter or first content line.
final
- filePath → String
-
Absolute or resolved path to the template file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (filename without
.md).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited