ServerSentEvent class final
A parsed Server-Sent Event.
Ported from pi's ServerSentEvent.
Constructors
-
ServerSentEvent({required String? event, required String data, required List<
String> raw})
Properties
- data → String
-
The
data:field values joined with\n(multi-line data per the SSE spec).final - event → String?
-
The
event:field value, ornullwhen the event had none.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ List<
String> -
The raw lines that made up this event, for diagnostics.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited