SessionContext class final
The model-derived state of a session along the active branch.
Ported from pi's SessionContext.
Constructors
-
SessionContext({required List<
Message> messages, required String thinkingLevel, required ({String modelId, String provider})? model, required List<String> ? activeToolNames}) -
Creates a SessionContext.
const
Properties
-
activeToolNames
→ List<
String> ? -
The active tool names in effect at the leaf, if ever set.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
Message> -
The rebuilt conversation context, oldest first.
final
- model → ({String modelId, String provider})?
-
The model in effect at the leaf, from the last
model_changerecord or assistant message.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thinkingLevel → String
-
The thinking level in effect at the leaf (
offby default).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited