Shell execution capability used by the harness.
Ported from pi's Shell interface. Implementations that cannot spawn
processes (e.g. web) should return ExecutionErrorCode.shellUnavailable.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exec(
String command, {ShellExecOptions? options}) → Future< Result< ShellExecResult, ExecutionError> > - Executes a shell command. Must never throw: all failures are encoded in the returned Result.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited