ShellExecOptions class final

Options for Shell.exec.

Constructors

ShellExecOptions({String? cwd, Map<String, String>? env, Duration? timeout, CancelToken? cancelToken, void onStdout(String chunk)?, void onStderr(String chunk)?})
Creates ShellExecOptions.
const

Properties

cancelToken CancelToken?
Token used to terminate the command early.
final
cwd String?
Working directory for the command. Defaults to FileSystem.cwd.
final
env Map<String, String>?
Additional environment variables; values override the defaults.
final
hashCode int
The hash code for this object.
no setterinherited
onStderr → void Function(String chunk)?
Called with stderr chunks as they are produced.
final
onStdout → void Function(String chunk)?
Called with stdout chunks as they are produced.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
Timeout for the command. Implementations should return a ExecutionErrorCode.timeout error when exceeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited