select abstract method
Runs sql with positional parameters and returns the rows. When
maxRows is given, iteration stops after that many rows and
SqliteRows.truncated reports whether more were available.
Implementation
SqliteRows select(
String sql, {
List<Object?> parameters = const [],
int? maxRows,
});