SseDecoder class
Decodes a stream of text chunks into ServerSentEvents.
Handles LF, CRLF, and lone-CR line endings, events split across chunks,
comment (:) lines, and multi-line data: fields. A trailing event not
terminated by a blank line is flushed when the input stream closes —
matching pi's behavior.
- Inheritance
-
- Object
- StreamTransformerBase<
String, ServerSentEvent> - SseDecoder
Constructors
- SseDecoder()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< String> stream) → Stream<ServerSentEvent> -
Transforms the provided
stream.override -
cast<
RS, RT> () → StreamTransformer< RS, RT> -
Provides a
StreamTransformer<RS, RT>view of this stream transformer.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited