StopReason enum
Why the assistant message stream terminated.
Ported from pi's StopReason union.
Values
- stop → const StopReason
-
The model finished naturally.
- length → const StopReason
-
The model hit the token limit.
- toolUse → const StopReason
-
The model stopped to invoke one or more tools.
- error → const StopReason
-
The stream failed (network error, malformed SSE, provider error, ...).
- aborted → const StopReason
-
The stream was cancelled via a
CancelToken.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StopReason> - A constant List of the values in this enum, in order of their declaration.