StreamingBlock class sealed
Mutable streaming accumulation for one content block. Converted into an immutable ContentBlock for every event snapshot.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContentBlock(
{bool finalize = false}) → ContentBlock - Converts to the immutable ContentBlock carried by event snapshots.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited