TextStreamingBlock class final
Accumulating text content block.
- Inheritance
-
- Object
- StreamingBlock
- TextStreamingBlock
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → StringBuffer
-
The accumulated text.
final
- textSignature ↔ String?
-
Provider-specific opaque signature for this block (Google
thoughtSignatureon a text part), when reported.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContentBlock(
{bool finalize = false}) → ContentBlock -
Converts to the immutable ContentBlock carried by event snapshots.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited