ToolNotFoundException class
Thrown when a tool referenced by the model is not registered.
- Inheritance
-
- Object
- AgentHarnessException
- ToolNotFoundException
Constructors
- ToolNotFoundException(String toolName)
-
Creates a ToolNotFoundException for
toolName.
Properties
- cause → Object?
-
The original error that caused this exception, if any.
finalinherited
- causeStack → StackTrace?
-
The stack trace of the original error, if any.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of what went wrong.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
The name of the missing tool.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited