TrajectoryDiffLine class final
One line of a bounded text diff (the section that changed, with a few context lines on each side).
Constructors
- TrajectoryDiffLine(String kind, String text)
-
Creates a diff line.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited