AiinCallback class final
One OAuth proxy redirect caught by AiinCallbackServer.
Constructors
- AiinCallback({String? code, String? state, String? error, String? errorDescription})
-
const
Properties
- code → String?
-
final
- error → String?
-
final
- errorDescription → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
final
- succeeded → bool
-
Whether the redirect carries a usable authorization code.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited