AiinCallbackServer class final
Loopback HTTP server catching the AIIN OAuth proxy redirect.
Constructors
Properties
- callbackUrl → String?
-
The redirect URI to register with initiateAiinOAuth
(
http://127.0.0.1:<ephemeral-port>/callback).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{Duration timeout = const Duration(minutes: 5)}) → Future< String> - Binds the loopback server and returns the redirect URI.
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForCallback(
) → Future< AiinCallback?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited