ChatGptOAuthLocalCallbackServer class final

Properties

callbackUrl → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({Duration timeout = const Duration(minutes: 5)}) → Future<String>
toString() → String
A string representation of this object.
inherited
waitForCallback() → Future<ChatGptOAuthCallback?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited