Sqlite3Engine class final
A SqliteEngine opening databases through package:sqlite3 (FFI).
- Implemented types
Constructors
- Sqlite3Engine()
-
Creates an engine.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openReadOnly(
String path) → SqliteDatabase -
Opens
pathread-only.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited